"""
This module maintains all importatnt methods exposed by PyTLDHunt library
"""
import json
import whois
from PyTLDHunt import constants

def check(domain: str, extension: str=None) -> dict:
    """This function will check if given domain.extension is available or not

    :param domain: domain name whose availability is needed to be checked
    :type domain: str
    :param extension: extension for domain, defaults to None
    :type extension: str, optional
    :return: returns dictionary of domain.extension as key and it's availability as value
    :rtype: dict
    """
    domain = str(domain)
    if extension is None:
        with open(
            file=constants.EXTENSIONS_FILE_PATH,
            mode=constants.EXTENSIONS_FILE_READ,
            encoding=constants.EXTENSIONS_FILE_ENC
        ) as f:
            extensions = json.load(f)[constants.EXTENSIONS_KEY]
    else:
        extensions = [str(extension)]

    response = {}
    for ext in extensions:
        __url = domain + constants.DNS_DELIMITER + ext
        try:
            _ = whois.whois(__url)
            response[__url] = constants.AVAIL
        except whois.parser.PywhoisError:
            response[__url] = constants.TAKEN
    return response
